@@ -1,6 +1,6 @@
 #' Dummy value indicating a required value.
 #'
-#' export
+#' @export
 optim_required <- function() {
   structure(list(), class = "optim_required")
 }
@@ -18,6 +18,12 @@ is_optimizer <- function(x) {
   inherits(x, "torch_optimizer")
 }
 
+#' @export
+print.torch_optimizer_generator <- function(x, ...) {
+  x <- attr(x, "Optimizer")
+  print(x)
+}
+
 Optimizer <- R6::R6Class(
   "torch_optimizer",
   lock_objects = FALSE,
@@ -26,7 +32,7 @@ Optimizer <- R6::R6Class(
       self$defaults <- defaults
       self$state <- list()
       self$param_groups <- list()
-      
+
       if (is_torch_tensor(params)) {
         param_groups <- list(list(params = list(params)))
       } else if (is.list(params) && is_torch_tensor(params[[1]])) {
@@ -36,23 +42,23 @@ Optimizer <- R6::R6Class(
       } else {
         value_error("Wrong parameters specification.")
       }
-      
+
       for (p in param_groups) {
         self$add_param_group(p)
       }
-      
+
       self$state <- State$new()
     },
     add_param_group = function(param_group) {
       if (!rlang::is_named(param_group)) {
         value_error("`param_group` is not named")
       }
-      
+
       params <- param_group$params
       if (is_torch_tensor(params)) {
         param_group$params <- list(params)
       }
-      
+
       for (param in param_group$params) {
         if (!is_torch_tensor(param)) {
           value_error(
@@ -60,13 +66,13 @@ Optimizer <- R6::R6Class(
             "but one of the params is {class(param)}"
           )
         }
-        
+
         if (!param$is_leaf) {
           value_error("can't optimize a non-leaf Tensor")
         }
       }
-      
-      
+
+
       for (nm in names(self$defaults)) {
         if (is_optim_required(self$defaults[[nm]]) && !nm %in% names(param_group)) {
           value_error(
@@ -77,53 +83,53 @@ Optimizer <- R6::R6Class(
           param_group[[nm]] <- self$defaults[[nm]]
         }
       }
-      
+
       # TODO: check for duplicated parameters
-      
+
       self$param_groups <- append(self$param_groups, list(param_group))
     },
-    zero_grad = function() {
+    zero_grad = function(set_to_none = FALSE) {
       for (group in self$param_groups) {
-        cpp_autograd_zero_grad(group$params)
+        cpp_autograd_zero_grad(group$params, set_to_none)
       }
     },
     state_dict = function() {
       parameters <- unlist(lapply(self$param_groups, function(x) x$params))
       parameters <- lapply(parameters, xptr_address)
-      
+
       state_dict <- self$state$map
       names(state_dict) <- match(names(self$state$map), parameters)
-      
+
       param_groups <- self$param_groups
       param_groups <- lapply(param_groups, function(x) {
         group_param <- lapply(x$params, xptr_address)
         x$params <- match(group_param, parameters)
         x
       })
-      
+
       list(
         param_groups = param_groups,
         state = state_dict
       )
     },
     load_state_dict = function(state_dict, ..., .refer_to_state_dict = FALSE) {
-      
+
       # validate the state dict
       if (!length(self$param_groups) == length(state_dict$param_groups)) {
         value_error("Loaded state dict has a different number of parameter groups")
       }
-      
+
       for (i in seq_along(self$param_groups)) {
         if (!length(self$param_groups[[i]]$params) == length(state_dict$param_groups[[i]]$params)) {
           value_error("Loaded state dict has contains a parameter group that doesn't match the size of optimizers group.")
         }
       }
-      
+
       parameters <- unlist(lapply(self$param_groups, function(x) x$params))
       # update state
       for (o in names(state_dict$state)) {
         index <- as.integer(o)
-        value <- state_dict$state[[o]]  
+        value <- state_dict$state[[o]]
         # when loading a state dict we shouldn't keep references to it by default
         # as this leads to hard to debug issues. Here we create copies of all tensors
         # in the state dict to avoid keeping the references. Note that if the state
@@ -133,7 +139,7 @@ Optimizer <- R6::R6Class(
           with_no_grad({
             value <- lapply(value, function(x) {
               if (is_torch_tensor(x))
-                torch_empty_like(x)$copy_(x)  
+                torch_empty_like(x)$copy_(x)
               else
                 x
             })
@@ -141,40 +147,43 @@ Optimizer <- R6::R6Class(
         }
         self$state$set(parameters[[index]], value)
       }
-      
+
       # we must also update the param groups
       for (i in seq_along(state_dict$param_groups)) {
         group <- state_dict$param_groups[[i]]
         for (nm in names(group)) {
           if (nm == "params") next
-          self$param_groups[[i]][[nm]] <- group[[nm]]    
+          self$param_groups[[i]][[nm]] <- group[[nm]]
         }
       }
-      
+
       invisible(self)
     }
   ),
   private = list(
+    deep_clone = function(name, value) {
+      stop("OptimizerIgnite cannot be deep cloned")
+    },
     step_helper = function(closure, loop_fun) {
       # a general template for most of the optimizer step function
       local_no_grad()
-      
+
       loss <- NULL
       if (!is.null(closure)) {
         with_enable_grad({
           loss <- closure()
         })
       }
-      
+
       for (g in seq_along(self$param_groups)) {
         group <- self$param_groups[[g]]
         for (p in seq_along(group$params)) {
           param <- group$params[[p]]
-          
+
           if (is.null(param$grad) || is_undefined_tensor(param$grad)) {
             next
           }
-          
+
           loop_fun(group, param, g, p)
         }
       }
@@ -267,6 +276,7 @@ state <- function(self) {
 #' }
 #' all.equal(x$item(), 0, tolerance = 1e-9)
 #' @includeRmd man/rmd/optim-note.Rmd note
+#' @include utils-data.R
 #' @export
 optimizer <- function(name = NULL, inherit = Optimizer, ...,
                       private = NULL, active = NULL,
